@@ -111,6 +111,12 @@ class SubmitCommand(SquadClientCommand):
 
                 data = tb
 
+        except IndexError as ie:
+            logger.error("Failed to load tuxbuild json due to a missing kconfig value: %s", ie)
+
+        except KeyError as ke:
+            logger.error("Failed to load tuxbuild json due to a missing variable: %s", ke)
+
         except json.JSONDecodeError as jde:
             logger.error("Failed to load json: %s", jde)
 
@@ -121,10 +127,14 @@ class SubmitCommand(SquadClientCommand):
 
     def _get_tuxbuild_test_name(self, build):
         suite = "build"
-        kconfig_hash = hashlib.sha1(json.dumps(build["kconfig"][1:]).encode()).hexdigest()[0:8]
 
-        return "%s/%s-%s-%s-%s" % (
-            suite, build["target_arch"], build["toolchain"], build["kconfig"][0], kconfig_hash,
+        if len(build["kconfig"][1:]):
+            kconfig = "%s-%s" % (build["kconfig"][0], hashlib.sha1(json.dumps(build["kconfig"][1:]).encode()).hexdigest()[0:8])
+        else:
+            kconfig = build["kconfig"][0]
+
+        return "%s/%s-%s" % (
+            suite, build["toolchain"], kconfig,
         )
 
     def run(self, args):
